package cn.com.ctop.performanceappraisal.controller;

import cn.com.ctop.performanceappraisal.entity.Performance;
import cn.com.ctop.performanceappraisal.service.IPerformanceService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.query.QueryGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;
import java.util.Map;

/**
 * 设计师季度绩效表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2019-12-10
 */
@Slf4j
@Api(tags = "设计师季度绩效表")
@RestController
@RequestMapping("/ctop/performance")
public class PerformanceController {
    @Autowired
    private IPerformanceService performanceService;

    /**
     * 分页列表查询
     *
     * @param performance
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @AutoLog(value = "设计师季度绩效表-分页列表查询")
    @ApiOperation(value = "设计师季度绩效表-分页列表查询", notes = "设计师季度绩效表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<Performance>> queryPageList(Performance performance,
                                                    @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                    @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                    HttpServletRequest req) {
        Result<IPage<Performance>> result = new Result<IPage<Performance>>();
        QueryWrapper<Performance> queryWrapper = QueryGenerator.initQueryWrapper(performance, req.getParameterMap());
        Page<Performance> page = new Page<Performance>(pageNo, pageSize);
        IPage<Performance> pageList = performanceService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }

    /**
     * 添加
     *
     * @param performance
     * @return
     */
    @AutoLog(value = "设计师季度绩效表-添加")
    @ApiOperation(value = "设计师季度绩效表-添加", notes = "设计师季度绩效表-添加")
    @PostMapping(value = "/add")
    public Result<Performance> add(@RequestBody Performance performance) {
        Result<Performance> result = new Result<Performance>();
        try {
            performanceService.save(performance);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param performance
     * @return
     */
    @AutoLog(value = "设计师季度绩效表-编辑")
    @ApiOperation(value = "设计师季度绩效表-编辑", notes = "设计师季度绩效表-编辑")
    @PutMapping(value = "/edit")
    public Result<Performance> edit(@RequestBody Performance performance) {
        Result<Performance> result = new Result<Performance>();
        Performance performanceEntity = performanceService.getById(performance.getId());
        if (performanceEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = performanceService.updateById(performance);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "设计师季度绩效表-通过id删除")
    @ApiOperation(value = "设计师季度绩效表-通过id删除", notes = "设计师季度绩效表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        try {
            performanceService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "设计师季度绩效表-批量删除")
    @ApiOperation(value = "设计师季度绩效表-批量删除", notes = "设计师季度绩效表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<Performance> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        Result<Performance> result = new Result<Performance>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.performanceService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "设计师季度绩效表-通过id查询")
    @ApiOperation(value = "设计师季度绩效表-通过id查询", notes = "设计师季度绩效表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<Performance> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<Performance> result = new Result<Performance>();
        Performance performance = performanceService.getById(id);
        if (performance == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(performance);
            result.setSuccess(true);
        }
        return result;
    }

    @GetMapping("/project/list")
    public Map<String, Object> projectList(@RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                           @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        return performanceService.getUserOptimizerProjectList(pageNo, pageSize);
    }

    @GetMapping("/account/list")
    public Map<String, Object> accountList(@RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                           @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize, Long projectId) {
        return performanceService.getUserOptimizerAccountList(projectId, pageNo, pageSize);
    }
}
